==> jscommunicator-1.0.21.tgz: package/lib/otpSms.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');
var DateTime = require('node-datetime');

var OtpSms = function (_base$Base) {
  _inherits(OtpSms, _base$Base);

  function OtpSms(host, config, appName) {
    _classCallCheck(this, OtpSms);

    return _possibleConstructorReturn(this, (OtpSms.__proto__ || Object.getPrototypeOf(OtpSms)).call(this, host, config, appName));
  }

  _createClass(OtpSms, [{
    key: 'createOtpJob',
    value: function createOtpJob(transactionId, transactionType, to, otp, maxRetry, expiryTime) {
      var isNewTemplate = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;

      var job = new types.Otp();
      job.transaction_id = transactionId;
      job.transaction_type = transactionType;
      job.mobile = to;
      job.app_name = this.appName;
      job.otp = otp;
      job.expiry_time = expiryTime;
      job.max_retry = maxRetry;
      job.is_new_template = isNewTemplate;
      this.validate(job);
      return job;
    }
  }, {
    key: 'validate',
    value: function validate(job) {
      if (!job.otp) {
        throw "OTP is missing";
      }
      if (!job.transaction_id) {
        throw "transactionId is missing";
      }
      if (!job.transaction_yype) {
        throw "transactionType is missing";
      }
      if (!job.mobile) {
        throw "mobile is missing";
      }
      if (!job.app_name) {
        throw "appName is missing";
      }
      if (!job.max_retry) {
        throw "maxRetry is missing";
      }
      if (job.max_retry > 10) {
        throw "Max retry should be less than 10";
      }
    }
  }, {
    key: 'getTransactionId',
    value: function getTransactionId() {
      var currentTime = +new Date() / 1000;
      var base = "abcdefghijklmnopqrstuvwxyz0123456789";
      var ret = parseInt(currentTime).toString() + '|';
      for (var i = 0; i < 20; i++) {
        ret = ret + base[Math.floor(Math.random() * (base.length - 0) + 0)];
      }
      return ret;
    }
  }, {
    key: 'sendCall',
    value: function sendCall(transactionId, transactionType, to, otp) {
      var maxRetry = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 10;
      var expiryTime = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : null;

      var job = this.createOtpJob(transactionId, transactionType, to, otp, maxRetry, expiryTime);
      this.send(job, this.queue.sendCallOtpQueue, 0);
    }
  }, {
    key: 'sendSms',
    value: function sendSms(transactionId, transactionType, to, otp) {
      var maxRetry = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 10;
      var expiryTime = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : null;
      var isNewTemplate = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;

      var job = this.createOtpJob(transactionId, transactionType, to, otp, maxRetry, expiryTime, isNewTemplate);
      this.send(job, this.queue.sendSmsOtpQueue, 0);
    }
  }, {
    key: 'completeOtpTransaction',
    value: function completeOtpTransaction(transactionId, mobile, otp) {
      var job = {};
      job.transaction_id = transactionId;
      job.mobile = mobile;
      job.otp = otp;
      job.completed_at = DateTime.create().format('Y-M-d H:M:S');
      this.send(job, this.queue.completeOtpTransaction, 0);
    }
  }]);

  return OtpSms;
}(base.Base);

module.exports = {
  OtpSms: OtpSms
};

==> jscommunicator-1.0.27.tgz: package/lib/otpSms.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');
var DateTime = require('node-datetime');

var OtpSms = function (_base$Base) {
  _inherits(OtpSms, _base$Base);

  function OtpSms(request, config, appName) {
    _classCallCheck(this, OtpSms);

    return _possibleConstructorReturn(this, (OtpSms.__proto__ || Object.getPrototypeOf(OtpSms)).call(this, request, config, appName));
  }

  _createClass(OtpSms, [{
    key: 'createOtpJob',
    value: function createOtpJob(transactionId, transactionType, to, otp, maxRetry, expiryTime) {
      var isNewTemplate = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;

      var job = new types.Otp();
      job.transaction_id = transactionId;
      job.transaction_type = transactionType;
      job.mobile = to;
      job.app_name = this.appName;
      job.otp = otp;
      job.expiry_time = expiryTime;
      job.max_retry = maxRetry;
      job.is_new_template = isNewTemplate;
      this.validate(job);
      return job;
    }
  }, {
    key: 'validate',
    value: function validate(job) {
      if (!job.otp) {
        throw "OTP is missing";
      }
      if (!job.transaction_id) {
        throw "transactionId is missing";
      }
      if (!job.transaction_yype) {
        throw "transactionType is missing";
      }
      if (!job.mobile) {
        throw "mobile is missing";
      }
      if (!job.app_name) {
        throw "appName is missing";
      }
      if (!job.max_retry) {
        throw "maxRetry is missing";
      }
      if (job.max_retry > 10) {
        throw "Max retry should be less than 10";
      }
    }
  }, {
    key: 'getTransactionId',
    value: function getTransactionId() {
      var currentTime = +new Date() / 1000;
      var base = "abcdefghijklmnopqrstuvwxyz0123456789";
      var ret = parseInt(currentTime).toString() + '|';
      for (var i = 0; i < 20; i++) {
        ret = ret + base[Math.floor(Math.random() * (base.length - 0) + 0)];
      }
      return ret;
    }
  }, {
    key: 'sendCall',
    value: function sendCall(transactionId, transactionType, to, otp) {
      var maxRetry = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 10;
      var expiryTime = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : null;

      var job = this.createOtpJob(transactionId, transactionType, to, otp, maxRetry, expiryTime);
      this.send(job, this.queue.sendCallOtpQueue, 0);
    }
  }, {
    key: 'sendSms',
    value: function sendSms(transactionId, transactionType, to, otp) {
      var maxRetry = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 10;
      var expiryTime = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : null;
      var isNewTemplate = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;

      var job = this.createOtpJob(transactionId, transactionType, to, otp, maxRetry, expiryTime, isNewTemplate);
      this.send(job, this.queue.sendSmsOtpQueue, 0);
    }
  }, {
    key: 'completeOtpTransaction',
    value: function completeOtpTransaction(transactionId, mobile, otp) {
      var job = {};
      job.transaction_id = transactionId;
      job.mobile = mobile;
      job.otp = otp;
      job.completed_at = DateTime.create().format('Y-M-d H:M:S');
      this.send(job, this.queue.completeOtpTransaction, 0);
    }
  }]);

  return OtpSms;
}(base.Base);

module.exports = {
  OtpSms: OtpSms
};
